@@ -1,9 +1,10 @@
 """
 URLs for the wagtail admin dashboard.
 """
-
 from django.urls import path
-from wagtailcache.views import index, clear
+
+from wagtailcache.views import clear
+from wagtailcache.views import index
 
 
 urlpatterns = [
